@@ -13,9 +13,7 @@ class SkOptAlgoWrapper():
 	def create(self, metric, mode, search_space, **args):
 		search_space = SkOptSpace(search_space).search_space
 		optimizer = Optimizer(search_space)
-		hp_names = []
-		for hp in search_space:
-			hp_names.append(hp.name)
+		labels = [hp.name for hp in search_space]
 
-		self.algorithm = SkOptSearch(optimizer, hp_names, metric=metric, mode=mode, **args)
+		self.algorithm = SkOptSearch(optimizer, labels, metric=metric, mode=mode, **args)
 		return self.algorithm
\ No newline at end of file
