@@ -59,6 +59,8 @@ class JobBuilder():
         for device in ['cpu', 'gpu']:
             if resource[device] >= self.max_concurrent:
                 resource_per_trial[device] = int(resource[device]/self.max_concurrent)  
+            elif resource[device] > 0:
+                resource_per_trial[device] = resource[device]/self.max_concurrent
             else:
                 resource_per_trial[device] = 0
         max_concurrent = self.max_concurrent
@@ -299,10 +301,9 @@ class JobBuilder():
         # save something to prevent looping job
         with open(kGridSiteMetadataFileName,'w') as output:
             json.dump({}, output)
-        #ray.init(node_ip_address="127.0.0.1", ignore_reinit_error=True)
         try:
-            #ray.init()
-
+            ray.init(include_dashboard=False,
+                     lru_evict=True)
             analysis = tune.run(
                 model,
                 name=self.project_name,
@@ -314,6 +315,8 @@ class JobBuilder():
                 verbose=self.verbose,
                 local_dir=self.log_dir,
                 stop=self.stop,
+                sync_to_driver=False,
+                fail_fast=True,
                 raise_on_failed_trial=False)
         finally:
             ray.shutdown()
