@@ -168,5 +168,6 @@ class ConfigurationBase():
 
     def show(self, name):
         config = self.load_config(name)
-        table = stylus.create_table(config.items(), self.show_columns, indexed=False)
-        print(table)
+        #table = stylus.create_table(config.items(), self.show_columns, indexed=False)
+        table = stylus.create_formated_dict(config, self.show_columns, indexed=False)
+        print(table)  
