@@ -41,9 +41,4 @@ class ModelConfiguration(ConfigurationBase):
                 print('ERROR: Cannot decode input param into json format. Please check your input.')
                 return None
 
-        return config
-    
-    def show(self, name):
-        config = self.load_config(name)
-        table = stylus.create_formated_dict(config, self.show_columns, indexed=False)
-        print(table)       
+        return config 
